package com.muyu.goods.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.goods.domain.Admin;
import com.muyu.goods.service.IAdminService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 测试信息Controller
 *
 * @author muyu
 * @date 2024-04-21
 */
@RestController
@RequestMapping("/admin")
public class AdminController extends BaseController
{
    @Autowired
    private IAdminService adminService;

    /**
     * 查询测试信息列表
     */
    @RequiresPermissions("goods:admin:list")
    @GetMapping("/list")
    public Result<TableDataInfo<Admin>> list(Admin admin)
    {
        startPage();
        List<Admin> list = adminService.selectAdminList(admin);
        return getDataTable(list);
    }

    /**
     * 导出测试信息列表
     */
    @RequiresPermissions("goods:admin:export")
    @Log(title = "测试信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Admin admin)
    {
        List<Admin> list = adminService.selectAdminList(admin);
        ExcelUtil<Admin> util = new ExcelUtil<Admin>(Admin.class);
        util.exportExcel(response, list, "测试信息数据");
    }

    /**
     * 获取测试信息详细信息
     */
    @RequiresPermissions("goods:admin:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(adminService.selectAdminById(id));
    }

    /**
     * 新增测试信息
     */
    @RequiresPermissions("goods:admin:add")
    @Log(title = "测试信息", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody Admin admin)
    {
        return toAjax(adminService.insertAdmin(admin));
    }

    /**
     * 修改测试信息
     */
    @RequiresPermissions("goods:admin:edit")
    @Log(title = "测试信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody Admin admin)
    {
        return toAjax(adminService.updateAdmin(admin));
    }

    /**
     * 删除测试信息
     */
    @RequiresPermissions("goods:admin:remove")
    @Log(title = "测试信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(adminService.deleteAdminByIds(ids));
    }
}
