package com.muyu.system.controller;

import java.sql.SQLException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.system.domain.DataAccess;
import com.muyu.system.service.IDataAccessService;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 数据接入Controller
 *
 * @author muyu
 * @date 2024-04-21
 */
@RestController
@RequestMapping("/access")
public class DataAccessController extends BaseController
{
    @Autowired
    private IDataAccessService dataAccessService;

    /**
     * 查询数据接入列表
     */
    @RequiresPermissions("system:access:list")
    @GetMapping("/list")
    public Result<TableDataInfo<DataAccess>> list(DataAccess dataAccess)
    {
        startPage();
        List<DataAccess> list = dataAccessService.selectDataAccessList(dataAccess);
        return getDataTable(list);
    }

    /**
     * 导出数据接入列表
     */
    @RequiresPermissions("system:access:export")
    @Log(title = "数据接入", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataAccess dataAccess)
    {
        List<DataAccess> list = dataAccessService.selectDataAccessList(dataAccess);
        ExcelUtil<DataAccess> util = new ExcelUtil<DataAccess>(DataAccess.class);
        util.exportExcel(response, list, "数据接入数据");
    }

    /**
     * 获取数据接入详细信息
     */
    @RequiresPermissions("system:access:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(dataAccessService.selectDataAccessById(id));
    }

    /**
     * 新增数据接入
     */
    @RequiresPermissions("system:access:add")
    @Log(title = "数据接入", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody DataAccess dataAccess) throws SQLException {
        return toAjax(dataAccessService.insertDataAccess(dataAccess));
    }

    /**
     * 修改数据接入
     */
    @RequiresPermissions("system:access:edit")
    @Log(title = "数据接入", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody DataAccess dataAccess)
    {
        return toAjax(dataAccessService.updateDataAccess(dataAccess));
    }

    /**
     * 删除数据接入
     */
    @RequiresPermissions("system:access:remove")
    @Log(title = "数据接入", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(dataAccessService.deleteDataAccessByIds(ids));
    }
}
