package com.muyu.system.controller;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.system.domain.DataSource;
import com.muyu.system.service.IDataSourceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 获取信息Controller
 *
 * @author muyu
 * @date 2024-04-21
 */
@RestController
@RequestMapping("/source")
public class DataSourceController extends BaseController
{
    @Autowired
    private IDataSourceService dataSourceService;

    /**
     * 查询获取信息列表
     */
    @RequiresPermissions("system:source:list")
    @GetMapping("/list")
    public Result<TableDataInfo<DataSource>> list(DataSource dataSource)
    {
        startPage();
        List<DataSource> list = dataSourceService.selectDataSourceList(dataSource);
        return getDataTable(list);
    }

    /**
     * 导出获取信息列表
     */
    @RequiresPermissions("system:source:export")
    @Log(title = "获取信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataSource dataSource)
    {
        List<DataSource> list = dataSourceService.selectDataSourceList(dataSource);
        ExcelUtil<DataSource> util = new ExcelUtil<DataSource>(DataSource.class);
        util.exportExcel(response, list, "获取信息数据");
    }

    /**
     * 获取获取信息详细信息
     */
    @RequiresPermissions("system:source:query")
    @GetMapping(value = "/{id}")
    public Result getInfo(@PathVariable("id") Long id)
    {
        return success(dataSourceService.selectDataSourceById(id));
    }

    /**
     * 新增获取信息
     */
    @RequiresPermissions("system:source:add")
    @Log(title = "获取信息", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add(@RequestBody DataSource dataSource)
    {
        return toAjax(dataSourceService.insertDataSource(dataSource));
    }

    /**
     * 修改获取信息
     */
    @RequiresPermissions("system:source:edit")
    @Log(title = "获取信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit(@RequestBody DataSource dataSource)
    {
        return toAjax(dataSourceService.updateDataSource(dataSource));
    }

    /**
     * 删除获取信息
     */
    @RequiresPermissions("system:source:remove")
    @Log(title = "获取信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public Result remove(@PathVariable Long[] ids)
    {
        return toAjax(dataSourceService.deleteDataSourceByIds(ids));
    }
}
