package com.muyu.system.service.impl;

import java.sql.SQLException;
import java.util.List;

import com.muyu.common.system.domain.SysDept;
import com.muyu.system.mapper.AccreditMapper;
import com.muyu.system.mapper.SysDeptMapper;
import com.muyu.system.service.AccreditService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.system.mapper.DataAccessMapper;
import com.muyu.system.domain.DataAccess;
import com.muyu.system.service.IDataAccessService;

/**
 * 数据接入Service业务层处理
 *
 * @author muyu
 * @date 2024-04-21
 */
@Service
public class DataAccessServiceImpl implements IDataAccessService
{
    @Autowired
    private DataAccessMapper dataAccessMapper;
    @Autowired
    private SysDeptMapper sysDeptMapper;
    @Autowired
    private AccreditService accreditService;

    /**
     * 查询数据接入
     *
     * @param id 数据接入主键
     * @return 数据接入
     */
    @Override
    public DataAccess selectDataAccessById(Long id)
    {
        return dataAccessMapper.selectDataAccessById(id);
    }

    /**
     * 查询数据接入列表
     *
     * @param dataAccess 数据接入
     * @return 数据接入
     */
    @Override
    public List<DataAccess> selectDataAccessList(DataAccess dataAccess)
    {
        return dataAccessMapper.selectDataAccessList(dataAccess);
    }

    /**
     * 新增数据接入
     *
     * @param dataAccess 数据接入
     * @return 结果
     */
    @Override
    public int insertDataAccess(DataAccess dataAccess) throws SQLException {
        int i = dataAccessMapper.insertDataAccess(dataAccess);
        List<SysDept> list = sysDeptMapper.listDeptList();
        DataAccess dataAccess1 = dataAccessMapper.oneDataAccess();
        for (SysDept sysDept : list) {
            dataAccessMapper.insertMiddle(sysDept.getDeptId(),dataAccess1.getId());
        }
        accreditService.listSqlJdbc();
        return i;
    }

    /**
     * 修改数据接入
     *
     * @param dataAccess 数据接入
     * @return 结果
     */
    @Override
    public int updateDataAccess(DataAccess dataAccess)
    {
        return dataAccessMapper.updateDataAccess(dataAccess);
    }

    /**
     * 批量删除数据接入
     *
     * @param ids 需要删除的数据接入主键
     * @return 结果
     */
    @Override
    public int deleteDataAccessByIds(Long[] ids)
    {
        return dataAccessMapper.deleteDataAccessByIds(ids);
    }

    /**
     * 删除数据接入信息
     *
     * @param id 数据接入主键
     * @return 结果
     */
    @Override
    public int deleteDataAccessById(Long id)
    {
        return dataAccessMapper.deleteDataAccessById(id);
    }
}
