package com.muyu.system.service.impl;

import com.muyu.common.core.utils.DateUtils;
import com.muyu.system.domain.DataSource;
import com.muyu.system.mapper.DataSourceMapper;
import com.muyu.system.service.IDataSourceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 获取信息Service业务层处理
 *
 * @author muyu
 * @date 2024-04-21
 */
@Service
public class DataSourceServiceImpl implements IDataSourceService
{
    @Autowired
    private DataSourceMapper dataSourceMapper;

    /**
     * 查询获取信息
     *
     * @param id 获取信息主键
     * @return 获取信息
     */
    @Override
    public DataSource selectDataSourceById(Long id)
    {
        return dataSourceMapper.selectDataSourceById(id);
    }

    /**
     * 查询获取信息列表
     *
     * @param dataSource 获取信息
     * @return 获取信息
     */
    @Override
    public List<DataSource> selectDataSourceList(DataSource dataSource)
    {
        return dataSourceMapper.selectDataSourceList(dataSource);
    }

    /**
     * 新增获取信息
     *
     * @param dataSource 获取信息
     * @return 结果
     */
    @Override
    public int insertDataSource(DataSource dataSource)
    {
        dataSource.setCreateTime(DateUtils.getNowDate());
        return dataSourceMapper.insertDataSource(dataSource);
    }

    /**
     * 修改获取信息
     *
     * @param dataSource 获取信息
     * @return 结果
     */
    @Override
    public int updateDataSource(DataSource dataSource)
    {
        dataSource.setUpdateTime(DateUtils.getNowDate());
        return dataSourceMapper.updateDataSource(dataSource);
    }

    /**
     * 批量删除获取信息
     *
     * @param ids 需要删除的获取信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceByIds(Long[] ids)
    {
        return dataSourceMapper.deleteDataSourceByIds(ids);
    }

    /**
     * 删除获取信息信息
     *
     * @param id 获取信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceById(Long id)
    {
        return dataSourceMapper.deleteDataSourceById(id);
    }
}
